@@ -37,7 +37,9 @@ class GenericString(Bytes):
 
     # 8-bit charsets
     CHARSET_8BIT = set((
-        "ASCII", "MacRoman", "CP037",
+        "ASCII",
+        "MacRoman", "CP037",
+        "WINDOWS-1252", "WINDOWS-1253",
         "ISO-8859-1",  "ISO-8859-2",  "ISO-8859-3",  "ISO-8859-4",
         "ISO-8859-5",  "ISO-8859-6",  "ISO-8859-7",  "ISO-8859-8",
         "ISO-8859-9",  "ISO-8859-10", "ISO-8859-11",
