@@ -79,6 +79,7 @@ class UnicodeStdout:
         self.device.write(text)
 
 def initLocale():
+    # Only initialize locale once
     try:
         if initLocale.is_done:
             return
@@ -92,10 +93,14 @@ def initLocale():
     except (locale.Error, IOError):
         pass
 
+    # Get the terminal charset
     charset = getTerminalCharset()
-    sys.stdout = UnicodeStdout(sys.stdout, charset)
-    sys.stderr = UnicodeStdout(sys.stderr, charset)
-    return charset
+
+    if config.unicode_stdout:
+        # Replace stdout and stderr by unicode objet supporting unicode string
+        sys.stdout = UnicodeStdout(sys.stdout, charset)
+        sys.stderr = UnicodeStdout(sys.stderr, charset)
+        return charset
 
 def _dummy_gettext(text):
     return unicode(text)
@@ -153,6 +158,7 @@ CHARSET_CHARACTERS = (
     (set(u"©®éêè\xE0ç".encode("ISO-8859-1")), "ISO-8859-1"),
     (set(u"©®éêè\xE0ç€".encode("ISO-8859-15")), "ISO-8859-15"),
     (set(u"©®".encode("MacRoman")), "MacRoman"),
+    (set(u"εδηιθκμοΡσςυΈί".encode("ISO-8859-7")), "ISO-8859-7"),
 )
 
 def guessBytesCharset(bytes, default=None):
@@ -169,6 +175,8 @@ def guessBytesCharset(bytes, default=None):
     'ISO-8859-1'
     >>> guessBytesCharset("100 \xA4")
     'ISO-8859-15'
+    >>> guessBytesCharset('Word \xb8\xea\xe4\xef\xf3\xe7 - Microsoft Outlook 97 - \xd1\xf5\xe8\xec\xdf\xf3\xe5\xe9\xf2 e-mail')
+    'ISO-8859-7'
     """
     # Check for UTF BOM
     for bom_bytes, charset in UTF_BOMS:
